@@ -2,19 +2,10 @@ from random import randint
 from re import findall
 
 def create_key():
-    # generate key
-    key = str(randint(0,99999999999999999999999999999999999999999999999999))
-    key = [i for i in key]
-
-    for i in range(9 - len(key)):
-        key = [str(randint(1,9))] + key
-
-    for i in range(len(key)):
-        letter = key[i]
-        if letter == "0":
-            key[i] = str(randint(1,9))
-            
-    return "".join(key)
+    key = ""
+    for i in range(50):
+        key = key + str(randint(1,9))
+    return key
 
 def cipher(message,key):
     if "0" in key:
@@ -122,7 +113,8 @@ def changelog():
 0.0.9 - Test Version\
 0.1.0 - Update 0.0.6 was revisited and implemented\
 0.1.1 - Added changelog\
-0.1.2 - Bug fixes")
+0.1.3 - Bug fixes\
+0.1.4 - Made key generation more efficient")
 
 class InvalidKey(Exception):
     pass
